==> lfocus_0.519-1.tar.gz: lfocus-0.519/stop_focus.py <==
import gobject
import dbus
import pygtk
import gtk, math, os
import sys

#import time
timeout=0
double_click=0
diag_is_up=0
from dbus.mainloop.glib import DBusGMainLoop

class Table:
	def __init__(self):
		dbus_loop = DBusGMainLoop()
		self.bus = dbus.SystemBus(mainloop=dbus_loop)
		self.focus_button_obj = self.bus.get_object("org.freedesktop.Hal","/org/freedesktop/Hal/devices/platform_cam_focus")
		self.focus_button_iface = dbus.Interface(self.focus_button_obj, "org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.roger, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_focus")
		self.camera_button_obj = self.bus.get_object("org.freedesktop.Hal","/org/freedesktop/Hal/devices/platform_cam_launch")
		self.camera_button_iface = dbus.Interface(self.camera_button_obj, "org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.roger2, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_launch")
		
		if len(sys.argv)>1:
			self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
			gtk.main_quit()

	
     	def rled_on(event):
		os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity=3")
	def rled_off(event):
		os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity=0")		

	def show_diag(self,*args):
		def stopwatch(a,b,*args):
			self.dialog1.hide_all()
			#print b
			'''import hildon	#causes some dbus errors...		
			banner = hildon.hildon_banner_show_information(self.dialog1, "lfocus-64",   "capturing in "+str(b)+" seconds") 
			print 1000*b
			self.maintimer = gobject.timeout_add(1, self.tickerf,b,b,b)'''
			self.maintimer = gobject.timeout_add(1000*b, self.ticker3)
				
		global diag_is_up
		diag_is_up=1		
		self.dialog1=gtk.Dialog("Stopwatch")
		self.dialog1.connect("destroy", self.dialog1.hide_all)
		self.dialog1.set_size_request(800,50)
		table = gtk.Table(1, 5, True)
		button0=gtk.Button("0s")
		button5=gtk.Button("5s")
		button10=gtk.Button("10s")
		button15=gtk.Button("15s")
		button20=gtk.Button("20s")

		button0.connect("clicked", stopwatch,.01)
		button5.connect("clicked", stopwatch,5)
		button10.connect("clicked", stopwatch,10)
		button15.connect("clicked", stopwatch,15)
		button20.connect("clicked", stopwatch,20)

		table.attach(button0, 4, 5, 0, 1)
		table.attach(button5, 3, 4, 0, 1)
		table.attach(button10, 2,3, 0, 1)
		table.attach(button15, 1, 2, 0, 1)
		table.attach(button20, 0, 1, 0, 1)
		self.dialog1.vbox.add(table)
		self.dialog1.show_all()
		
		
	def ticker2(self):
		global timeout
		global double_click
		global diag_is_up
		if double_click==1 and timeout>4:
			#print ("double clicked!")
			if diag_is_up==1:
				self.dialog1.hide_all()
				diag_is_up=0
			self.show_diag()
			double_click=0
			timeout=0
		elif double_click<3:
			double_click=0
			timeout=0
	def ticker3(self):
		print ("Started")
		self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
	

	'''
	def tickerf(self,b,c,e):
		if b>0:
			b-=1
			d=e-b
			self.maintimer = gobject.timeout_add(1, self.tickerf2,b,c,d,e)	


	def tickerf2(self,b,c,d,e):
		print ("b="+str(b)+"c="+str(c)+"d="+str(d))
		d-=1
		if d>0:
			self.rled_on()
			self.rled_off()
			self.maintimer = gobject.timeout_add(1000/(e-b), self.tickerf2,b,c,d,e)
		elif c>0:
			c-=1
			self.maintimer = gobject.timeout_add(1, self.tickerf,b,c,e)
	'''
	def ticker(self):
		self.rled_off()
		#print("done")
	def roger2(self,a,b):
		self.maintimer = gobject.timeout_add(1000, self.ticker)

	def roger(self,a,b):
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		global timeout
		global double_click
		timeout+=1
		#print timeout

			
		if double_click==0 and timeout < 8:
			double_click=1
			self.maintimer = gobject.timeout_add(500, self.ticker2)

		
		if timeout>10 :
			#print timeout
			timeout=0
		
def main():
	gtk.main()
	return 0       
if __name__ == "__main__":
    Table()
    main()

==> lfocus_0.528-1.tar.gz: lfocus-0.528/stop_focus.py <==
import gobject
import dbus
import pygtk
import gtk, math, os
import sys

#import time
timeout=0
double_click=0
diag_is_up=0
from dbus.mainloop.glib import DBusGMainLoop

class Table:
	def __init__(self):
		dbus_loop = DBusGMainLoop()
		self.bus = dbus.SystemBus(mainloop=dbus_loop)
		self.focus_button_obj = self.bus.get_object("org.freedesktop.Hal","/org/freedesktop/Hal/devices/platform_cam_focus")
		self.focus_button_iface = dbus.Interface(self.focus_button_obj, "org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.roger, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_focus")
		self.camera_button_obj = self.bus.get_object("org.freedesktop.Hal","/org/freedesktop/Hal/devices/platform_cam_launch")
		self.camera_button_iface = dbus.Interface(self.camera_button_obj, "org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.roger2, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_launch")
		
		if len(sys.argv)>1:
			self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
			self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
			gtk.main_quit()

	
     	def rled_on(event):
		os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity=3")
	def rled_off(event):
		os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity=0")		

	def show_diag(self,*args):
		def stopwatch(a,b,*args):
			self.dialog1.hide_all()
			#print b
			'''import hildon	#causes some dbus errors...		
			banner = hildon.hildon_banner_show_information(self.dialog1, "lfocus-64",   "capturing in "+str(b)+" seconds") 
			print 1000*b
			self.maintimer = gobject.timeout_add(1, self.tickerf,b,b,b)'''
			self.maintimer = gobject.timeout_add(1000*b, self.ticker3)
				
		global diag_is_up
		diag_is_up=1		
		self.dialog1=gtk.Dialog("Stopwatch")
		self.dialog1.connect("destroy", self.dialog1.hide_all)
		self.dialog1.set_size_request(800,50)
		table = gtk.Table(1, 5, True)
		button0=gtk.Button("0s")
		button5=gtk.Button("5s")
		button10=gtk.Button("10s")
		button15=gtk.Button("15s")
		button20=gtk.Button("20s")

		button0.connect("clicked", stopwatch,.01)
		button5.connect("clicked", stopwatch,5)
		button10.connect("clicked", stopwatch,10)
		button15.connect("clicked", stopwatch,15)
		button20.connect("clicked", stopwatch,20)

		table.attach(button0, 4, 5, 0, 1)
		table.attach(button5, 3, 4, 0, 1)
		table.attach(button10, 2,3, 0, 1)
		table.attach(button15, 1, 2, 0, 1)
		table.attach(button20, 0, 1, 0, 1)
		self.dialog1.vbox.add(table)
		self.dialog1.show_all()
		
		
	def ticker2(self):
		global timeout
		global double_click
		global diag_is_up
		if double_click==1 and timeout>4:
			#print ("double clicked!")
			if diag_is_up==1:
				self.dialog1.hide_all()
				diag_is_up=0
			self.show_diag()
			double_click=0
			timeout=0
		elif double_click<3:
			double_click=0
			timeout=0
	def ticker3(self):
		print ("Started")
		self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",True)
		self.camera_button_iface.SetPropertyBoolean("button.state.value",False)
	

	'''
	def tickerf(self,b,c,e):
		if b>0:
			b-=1
			d=e-b
			self.maintimer = gobject.timeout_add(1, self.tickerf2,b,c,d,e)	


	def tickerf2(self,b,c,d,e):
		print ("b="+str(b)+"c="+str(c)+"d="+str(d))
		d-=1
		if d>0:
			self.rled_on()
			self.rled_off()
			self.maintimer = gobject.timeout_add(1000/(e-b), self.tickerf2,b,c,d,e)
		elif c>0:
			c-=1
			self.maintimer = gobject.timeout_add(1, self.tickerf,b,c,e)
	'''
	def ticker(self):
		self.rled_off()
		#print("done")
	def roger2(self,a,b):
		self.maintimer = gobject.timeout_add(1000, self.ticker)

	def roger(self,a,b):
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		global timeout
		global double_click
		timeout+=1
		#print timeout

			
		if double_click==0 and timeout < 8:
			double_click=1
			self.maintimer = gobject.timeout_add(500, self.ticker2)

		
		if timeout>10 :
			#print timeout
			timeout=0
		
def main():
	gtk.main()
	return 0       
if __name__ == "__main__":
    Table()
    main()
